@@ -1,5 +1,5 @@
 ;; 
-;;  Copyright (c) 2005-2008 uim Project http://code.google.com/p/uim/
+;;  Copyright (c) 2005-2009 uim Project http://code.google.com/p/uim/
 ;;
 ;;  All rights reserved.
 ;;
@@ -1224,7 +1224,7 @@
       (when helpermsg
 	(uim-helper-send-message helpermsg))
 
-      (when default
+      (when (and default (not (uim-get-default-engine)))
 	(uim-update-default-engine default))
 
       (when im
